pub enum GeneratorData {
Decrypted(ProvenanceMarkGenerator),
Encrypted(Envelope),
}Expand description
Provenance mark generator data that can be either decrypted or encrypted.
Variants
Decrypted(ProvenanceMarkGenerator)
Decrypted generator that can be used for mark generation.
Encrypted(Envelope)
Encrypted generator envelope that cannot be used without decryption. This preserves the encrypted assertion when a document is loaded without the decryption password.
Note: Envelope uses internal reference counting (Rc/Arc) so cloning is cheap - no need for additional wrapper.