pub enum XIDVerifySignature {
None,
Inception,
}Expand description
Options for verifying the signature on an envelope when loading an XIDDocument.
Variants
None
Do not verify the signature (default).
Inception
Verify that the envelope is signed with the inception key.