pub enum XIDPrivateKeyOptions {
Omit,
Include,
Elide,
Encrypt {
method: KeyDerivationMethod,
password: Vec<u8>,
},
}Expand description
Options for handling private keys in envelopes.
Variants
Omit
Omit the private key from the envelope (default).
Include
Include the private key in plaintext (with salt for decorrelation).
Elide
Include the private key assertion but elide it (maintains digest tree).
Encrypt
Include the private key encrypted with a password using the specified key derivation method.