pub struct Key { /* private fields */ }Implementations
Sourceimpl Key
impl Key
pub fn new(public_keys: impl AsRef<PublicKeys>) -> Self
pub fn new_allow_all(public_keys: impl AsRef<PublicKeys>) -> Self
pub fn new_with_private_keys( private_keys: PrivateKeys, public_keys: PublicKeys, ) -> Self
pub fn new_with_private_key_base(private_key_base: PrivateKeyBase) -> Self
pub fn public_keys(&self) -> &PublicKeys
pub fn private_keys(&self) -> Option<&PrivateKeys>
pub fn has_private_keys(&self) -> bool
pub fn has_encrypted_private_keys(&self) -> bool
pub fn private_key_salt(&self) -> Option<&Salt>
Sourcepub fn private_key_envelope(
&self,
password: Option<&str>,
) -> Result<Option<Envelope>>
pub fn private_key_envelope( &self, password: Option<&str>, ) -> Result<Option<Envelope>>
Extract the private key data as an Envelope, optionally decrypting it.
Returns
Ok(None)if no private key is presentOk(Some(Envelope))containing:- Decrypted
PrivateKeysif unencrypted - Decrypted
PrivateKeysif encrypted and correct password provided - Encrypted envelope if encrypted and no password provided
- Decrypted
Err(...)if encrypted and wrong password provided
Examples
use bc_components::PrivateKeyBase;
use bc_envelope::prelude::*;
use bc_xid::Key;
// Unencrypted key
let prvkey_base = PrivateKeyBase::new();
let key = Key::new_with_private_key_base(prvkey_base.clone());
let envelope = key.private_key_envelope(None).unwrap().unwrap();
// Returns envelope containing PrivateKeys
// Encrypted key without password
// Returns the encrypted envelope as-is
// Encrypted key with correct password
// Returns envelope containing decrypted PrivateKeyspub fn signing_public_key(&self) -> &SigningPublicKey
pub fn encapsulation_public_key(&self) -> &EncapsulationPublicKey
pub fn endpoints(&self) -> &HashSet<URI>
pub fn endpoints_mut(&mut self) -> &mut HashSet<URI>
pub fn add_endpoint(&mut self, endpoint: URI)
pub fn permissions(&self) -> &Permissions
pub fn permissions_mut(&mut self) -> &mut Permissions
pub fn add_permission(&mut self, privilege: Privilege)
Sourceimpl Key
impl Key
pub fn into_envelope_opt( self, private_key_options: XIDPrivateKeyOptions, ) -> Envelope
Sourceimpl Key
impl Key
Sourcepub fn try_from_envelope(
envelope: &Envelope,
password: Option<&[u8]>,
) -> Result<Self>
pub fn try_from_envelope( envelope: &Envelope, password: Option<&[u8]>, ) -> Result<Self>
Try to extract a Key from an envelope, optionally providing a
password to decrypt an encrypted private key.
If the private key is encrypted and no password is provided, the Key
will be created without the private key (it will be None).